Index: channels/chan_sip.c
===================================================================
--- channels/chan_sip.c	(revision 269416)
+++ channels/chan_sip.c	(working copy)
@@ -8520,6 +8520,15 @@
 					}
 				}
 				break;
+			case AST_FORMAT_G719:
+				if (sscanf(fmtp_string, "bitrate=%30u", &bit_rate) == 1) {
+					if (bit_rate != 64000) {
+						ast_log(LOG_WARNING, "Got G.719 offer at %d bps, but only 64000 bps supported; ignoring.\n", bit_rate);
+						ast_rtp_codecs_payloads_unset(newaudiortp, NULL, codec);
+					} else {
+						found = TRUE;
+					}
+				}
 			}
 		}
 	}
@@ -9771,6 +9780,10 @@
 		/* Indicate that we only expect 48Kbps */
 		ast_str_append(a_buf, 0, "a=fmtp:%d bitrate=48000\r\n", rtp_code);
 		break;
+	case AST_FORMAT_G719:
+		/* Indicate that we only expect 64Kbps */
+		ast_str_append(a_buf, 0, "a=fmtp:%d bitrate=64000\r\n", rtp_code);
+		break;
 	}
 
 	if (fmt.cur_ms && (fmt.cur_ms < *min_packet_size))
Index: channels/chan_iax2.c
===================================================================
--- channels/chan_iax2.c	(revision 269416)
+++ channels/chan_iax2.c	(working copy)
@@ -316,6 +316,7 @@
                      ~AST_FORMAT_SLINEAR16 &    \
                      ~AST_FORMAT_SIREN7 &       \
                      ~AST_FORMAT_SIREN14 &      \
+                     ~AST_FORMAT_G719 &         \
                      ~AST_FORMAT_ULAW &         \
                      ~AST_FORMAT_ALAW &         \
                      ~AST_FORMAT_G722)
Index: include/asterisk/frame.h
===================================================================
--- include/asterisk/frame.h	(revision 269416)
+++ include/asterisk/frame.h	(working copy)
@@ -294,6 +294,8 @@
 /*! Maximum text mask */
 #define AST_FORMAT_MAX_TEXT   (1ULL << 28)
 #define AST_FORMAT_TEXT_MASK  (((1ULL << 30)-1) & ~(AST_FORMAT_AUDIO_MASK) & ~(AST_FORMAT_VIDEO_MASK))
+/*! G.719 (64 kbps assumed) */
+#define AST_FORMAT_G719	      (1ULL << 32)
 /*! Raw mu-law data (G.711) */
 #define AST_FORMAT_TESTLAW       (1ULL << 47)
 /*! Reserved bit - do not use */
@@ -746,6 +748,8 @@
 		return 16000;
 	case AST_FORMAT_SIREN14:
 		return 32000;
+	case AST_FORMAT_G719:
+		return 48000;
 	default:
 		return 8000;
 	}
Index: main/channel.c
===================================================================
--- main/channel.c	(revision 269416)
+++ main/channel.c	(working copy)
@@ -792,6 +792,7 @@
 		AST_FORMAT_ULAW,
 		/*! Unless of course, you're a silly European, so then prefer ALAW */
 		AST_FORMAT_ALAW,
+		AST_FORMAT_G719,
 		AST_FORMAT_SIREN14,
 		AST_FORMAT_SIREN7,
 		AST_FORMAT_TESTLAW,
Index: main/frame.c
===================================================================
--- main/frame.c	(revision 269416)
+++ main/frame.c	(working copy)
@@ -120,6 +120,7 @@
 	{ AST_FORMAT_SIREN7, "siren7", 16000, "ITU G.722.1 (Siren7, licensed from Polycom)", 80, 20, 80, 20, 20 },			/*!< Binary commercial distribution */
 	{ AST_FORMAT_SIREN14, "siren14", 32000, "ITU G.722.1 Annex C, (Siren14, licensed from Polycom)", 120, 20, 80, 20, 20 },	/*!< Binary commercial distribution */
 	{ AST_FORMAT_TESTLAW, "testlaw", 8000, "G.711 test-law", 80, 10, 150, 10, 20 },                                 /*!< codec_ulaw.c */
+	{ AST_FORMAT_G719, "g719", 48000, "ITU G.719", 160, 20, 80, 20, 20 },
 };
 
 struct ast_frame ast_null_frame = { AST_FRAME_NULL, };
@@ -1489,6 +1490,10 @@
 		/* 32,000 samples per second at 48kbps is 6,000 bytes per second */
 		samples = (int) f->datalen * ((float) 32000 / 6000);
 		break;
+	case AST_FORMAT_G719:
+		/* 48,000 samples per second at 64kbps is 8,000 bytes per second */
+		samples = (int) f->datalen * ((float) 48000 / 8000);
+		break;
 	default:
 		ast_log(LOG_WARNING, "Unable to calculate samples for format %s\n", ast_getformatname_multiple(tmp, sizeof(tmp), f->subclass.codec));
 	}
@@ -1536,6 +1541,10 @@
 		/* 32,000 samples per second at 48kbps is 6,000 bytes per second */
 		len = (int) samples / ((float) 32000 / 6000);
 		break;
+	case AST_FORMAT_G719:
+		/* 48,000 samples per second at 64kbps is 8,000 bytes per second */
+		len = (int) samples / ((float) 48000 / 8000);
+		break;
 	default:
 		ast_log(LOG_WARNING, "Unable to calculate sample length for format %s\n", ast_getformatname(format));
 	}
Index: main/rtp_engine.c
===================================================================
--- main/rtp_engine.c	(revision 269416)
+++ main/rtp_engine.c	(working copy)
@@ -122,6 +122,7 @@
 	{{1, AST_FORMAT_T140}, "text", "T140", 1000},
 	{{1, AST_FORMAT_SIREN7}, "audio", "G7221", 16000},
 	{{1, AST_FORMAT_SIREN14}, "audio", "G7221", 32000},
+	{{1, AST_FORMAT_G719}, "audio", "G719", 48000},
 };
 
 /*!
@@ -169,6 +170,7 @@
 	[111] = {1, AST_FORMAT_G726},
 	[112] = {1, AST_FORMAT_G726_AAL2},
 	[115] = {1, AST_FORMAT_SIREN14},
+	[116] = {1, AST_FORMAT_G719},
 	[121] = {0, AST_RTP_CISCO_DTMF}, /* Must be type 121 */
 };
 
Index: res/res_rtp_asterisk.c
===================================================================
--- res/res_rtp_asterisk.c	(revision 269416)
+++ res/res_rtp_asterisk.c	(working copy)
@@ -1231,6 +1231,7 @@
 		case AST_FORMAT_G723_1:
 		case AST_FORMAT_SIREN7:
 		case AST_FORMAT_SIREN14:
+		case AST_FORMAT_G719:
 			/* these are all frame-based codecs and cannot be safely run through
 			   a smoother */
 			break;
